library(MASS)
library(lattice)
library(mgcv)
library(car)
library(ggplot2)
library(ggthemes)
require(survival)
require(psych)
require(survminer)
require(goftte)
library(coxme)
library(survival)


#Import the data from a tab delimited ascii file
data<- read.csv(file = "Data.csv",
                 header = TRUE,
                 dec = ".")
head(data)
data$Stage<-as.factor(data$Stage)
data$ID<-as.factor(data$ID)
data$Combined<-paste(data$Stage,data$Treatment)

### Survival analysis----

## tables
describeBy(data$days_alive, data$Dead, mat = TRUE)
table(data$Treatment, data$days_alive)
table(data$Stage, data$days_alive)


## Cox proportional hazards model without size:
fit <- coxme(Surv(data$days_alive, data$Dead) ~ data$Treatment*data$Stage + (1|data$Tank), 
             data = data)

summary(fit)
Anova(fit)
fitcoxph <- coxph(Surv(data$days_alive, data$Dead) ~ data$Treatment*data$Stage, 
                  data = data)
fitcox.zph <- cox.zph(fitcoxph)
Anova(fitcoxph)
ggcoxzph(fitcox.zph)

## Cox proportional hazards model with size:
fit <- coxme(Surv(data$days_alive, data$Dead) ~ data$Treatment*data$Stage*data$size + (1|data$Tank), 
             data = data)

summary(fit)
Anova(fit)
fitcoxph <- coxph(Surv(data$days_alive, data$Dead) ~ data$Treatment*data$Stage*data$size, 
                  data = data)
fitcox.zph <- cox.zph(fitcoxph)
Anova(fitcoxph)
ggcoxzph(fitcox.zph)

### Kaplan-Meier plot

c1 <- Surv(data$days_alive, data$Dead)
C1 <- survfit(c1~ Combined, data=data)


plot<-ggsurvplot(C1, data=data,
                 legend=c(0.2, 0.25),
                 conf.int = T, 
                 legend.title="Treatment",
                 ggtheme = theme_few(), 
                 palette = c("#4DBBD5FF", "#E64B35FF" ,"#00A087FF", "#3C5488FF" ,"#F39B7FFF" ,"#8491B4FF"),
                 alpha=1,
                 ylab="Survival rate",
                 xlab="Days",
                 legend.lab = c("Stage 1 - Control", "Stage 1 - High CO2", "Stage 2 - Control", "Stage 2 - High CO2","Stage 3 - Control", "Stage 3 - High CO2"))
plot
